@@ -102,7 +102,7 @@ class Response(io.BytesIO):
         self.status = status
         self.headers = headers or {}
         self.reason = requests.status_codes._codes.get(
-            status, [''])[0].upper().replace('_', ' ')
+            status, [''])[0].upper().replace('_', ' ')  # nosec
         io.BytesIO.__init__(self, stream)
 
     @property
@@ -209,6 +209,25 @@ class MemoryCache(cache.ObjectCache):
 _CACHE = MemoryCache()
 
 
+class CompatibilitySudsClient(client.Client):
+    """suds client with added cookiejar attribute
+
+    The cookiejar properties allow reading/setting the cookiejar used by the
+    underlying transport.
+    """
+    def __init__(self, *args, **kwargs):
+        super(CompatibilitySudsClient, self).__init__(*args, **kwargs)
+
+    @property
+    def cookiejar(self):
+        return self.options.transport.cookiejar
+
+    @cookiejar.setter
+    def cookiejar(self, cookies):
+        self.options.transport.session.cookies = cookies
+        self.options.transport.cookiejar = cookies
+
+
 class Service(object):
     """Base class containing common functionality for invoking vSphere
     services
@@ -226,11 +245,11 @@ class Service(object):
                                       insecure=insecure,
                                       pool_maxsize=pool_maxsize,
                                       connection_timeout=connection_timeout)
-        self.client = client.Client(self.wsdl_url,
-                                    transport=transport,
-                                    location=self.soap_url,
-                                    plugins=[ServiceMessagePlugin()],
-                                    cache=_CACHE)
+        self.client = CompatibilitySudsClient(self.wsdl_url,
+                                              transport=transport,
+                                              location=self.soap_url,
+                                              plugins=[ServiceMessagePlugin()],
+                                              cache=_CACHE)
         self._service_content = None
         self._vc_session_cookie = None
 
@@ -274,7 +293,8 @@ class Service(object):
                         f_name = f_type.__class__.__name__
                         fault_list.append(f_name)
                         if f_name == exceptions.NO_PERMISSION:
-                            details['object'] = f_type.object.value
+                            details['object'] = \
+                                vim_util.get_moref_value(f_type.object)
                             details['privilegeId'] = f_type.privilegeId
 
         if fault_list:
@@ -311,7 +331,7 @@ class Service(object):
 
     def get_http_cookie(self):
         """Return the vCenter session cookie."""
-        cookies = self.client.options.transport.cookiejar
+        cookies = self.client.cookiejar
         for cookie in cookies:
             if cookie.name.lower() == 'vmware_soap_session':
                 return cookie.value
@@ -349,7 +369,7 @@ class Service(object):
                     op_id = '%s-%s' % (self.op_id_prefix,
                                        uuidutils.generate_uuid())
                     LOG.debug('Invoking %s.%s with opID=%s',
-                              managed_object._type,
+                              vim_util.get_moref_type(managed_object),
                               attr_name,
                               op_id)
                 self._set_soap_headers(op_id)
